#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
from trytond.model import fields
from trytond.pool import PoolMeta
from trytond.transaction import Transaction

__all__ = ['Employee']
__metaclass__ = PoolMeta


class Employee:
    __name__ = 'company.employee'
    active = fields.Boolean('Active', select=True)
    code = fields.Char('Code', size=None, select=True)
    salary = fields.Property(fields.Numeric('Salary', digits=(16, 2), 
            help='Salary monthly of person'))
    type_contract = fields.Selection([
            ('steady', 'Steady'),
            ('indefinite', 'Indefinite'),
            ('job', 'Job')
            ], 'Type Contract', select=True)
    start_contract = fields.Date('Start Contract')
    end_contract = fields.Date('End Contract')
    position = fields.Many2One('staff.position', 'Position', 
            select=True)
    curses = fields.Text('Curses')
    career = fields.Text('Career')
    contracting_state = fields.Selection([
            ('', ''),
            ('process', 'Process'),
            ('rejected', 'Rejected'),
            ('accepted', 'Accepted'),
            ('finished', 'Finished'),
            ], 'Contracting State')

    @classmethod
    def __setup__(cls):
        super(Employee, cls).__setup__()

    @staticmethod
    def default_type_contract():
        return 'job'

    @staticmethod
    def default_active():
        return True

    @staticmethod
    def default_contracting_state():
        return 'process'

    @staticmethod
    def default_company():
        return Transaction().context.get('company')
